@@ -1,6 +1,6 @@
 #include "ruby.h"
 
-VALUE method_answer42(VALUE module, VALUE self);
+VALUE method_answer42(VALUE module);
 
 void Init_baz() {
   VALUE BAZ = rb_define_module("BAZ");
@@ -8,6 +8,6 @@ void Init_baz() {
   rb_define_const(BAZ, "Hello_world", rb_str_new2("Hello World"));
 }
 
-VALUE method_answer42(VALUE module, VALUE self) {
+VALUE method_answer42(VALUE module) {
 	return INT2NUM(42);
 }
