@@ -16,21 +16,19 @@ class TestRunnerTest < Gem2DebTestCase
     should "exit #{exitstatus} when testing #{dir}" do
       begin
         Dir.chdir(dir) do
-          self.class.silence_stream(STDOUT) do
-            self.class.silence_stream(STDERR) do
-              runner = Gem2Deb::TestRunner.detect
-              runner.autopkgtest = autopkgtest
-              def runner.exec(*cmd)
-                system(*cmd)
-                exit($?.exitstatus)
-              end
-              rubylib = ENV['RUBYLIB']
-              ENV['RUBYLIB'] = GEM2DEB_ROOT_SOURCE_DIR + '/lib'
-              begin
-                runner.run_tests
-              ensure
-                ENV['RUBYLIB'] = rubylib
-              end
+          self.class.silently do
+            runner = Gem2Deb::TestRunner.detect
+            runner.autopkgtest = autopkgtest
+            def runner.exec(*cmd)
+              system(*cmd)
+              exit($?.exitstatus)
+            end
+            rubylib = ENV['RUBYLIB']
+            ENV['RUBYLIB'] = GEM2DEB_ROOT_SOURCE_DIR + '/lib'
+            begin
+              runner.run_tests
+            ensure
+              ENV['RUBYLIB'] = rubylib
             end
           end
         end
